/****************************************************************************
**
** Copyright (C) 2019 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <utils/smallstringvector.h>

#include "sqliteglobal.h"

namespace Sqlite {
class DatabaseInterface
{
public:
    virtual void walCheckpointFull() = 0;
    virtual void execute(Utils::SmallStringView sqlStatement) = 0;
    virtual void setUpdateHook(
        void *object,
        void (*)(void *object, int, char const *database, char const *, long long rowId))
        = 0;
    virtual void resetUpdateHook() = 0;
    virtual void applyAndUpdateSessions() = 0;
    virtual void setAttachedTables(const Utils::SmallStringVector &tables) = 0;

protected:
    ~DatabaseInterface() = default;
};
} // namespace Sqlite
